![logo_with_text](https://github.com/geniusrise/.github/assets/144122/2f8e51ee-0fcd-4f74-90fd-97301ef7943d)

### AI Ecosystem

<h3 align="center">
  <a style="color:#f34960" href="https://docs.geniusrise.ai">Documentation</a>
  ||
  <a style="color:#f34960" href="https://github.com/geniusrise/examples">Examples</a>
  ||
  <a style="color:#f34960" href="https://geniusrise.com">Cloud</a>
</h3>

### <span style="color:#e667aa">About</span>

<span style="color:#e4e48c">Geniusrise</span> is a modular, loosely-coupled
MLOps framework designed for the era of Large Language Models,
offering flexibility and standardization in designing networks of
AI agents.

It defines components and orchestrates them providing observability, state management and data handling,
all while supporting diverse infrastructures. With its modular and unopinonated architecture,
<span style="color:#e4e48c">Geniusrise</span> empowers teams to build, share,
and deploy AI across various platforms.

Geniusrise is powered by its components:

- [geniusrise-text](https://github.com/geniusrise/geniusrise-text): Text components offerring:
  - Inference APIs
  - Bulk inference
  - Fine-tuning
- [geniusrise-audio](https://github.com/geniusrise/geniusrise-audio): Audio components offerring:
  - Inference APIs
  - Bulk inference
  - Fine-tuning
- [geniusrise-vision](https://github.com/geniusrise/geniusrise-vision): Vision components offerring:
  - Inference APIs
  - Bulk inference
  - Fine-tuning
- [geniusrise-listeners](https://github.com/geniusrise/geniusrise-listeners): Streaming data ingestion
- [geniusrise-databases](https://github.com/geniusrise/geniusrise-databases): Bulk data ingestion

### <span style="color:#e667aa">Links</span>

- **Website**: [geniusrise.ai](https://geniusrise.ai)
- **Docs**: [docs.geniusrise.ai](https://docs.geniusrise.ai)
- **Examples**: [geniusrise/examples](https://github.com/geniusrise/examples)
- **Cloud**: [geniusrise.com](https://geniusrise.com)

# Vision Components

These are vision components, mainly focused around models of the vision modality (either input or output).

